"use strict";

var _react = require("@testing-library/react");
var _vitest = require("vitest");
require("@testing-library/jest-dom");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
var _index = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _TruncateText, _TruncateText2, _TruncateText3, _TruncateText4, _TruncateText5;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
const defaultText = 'Hello world! This is a long string that should truncate';
describe('<TruncateText />', () => {
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleErrorMock.mockRestore();
  });
  it('should warn if children prop receives too deep of a node tree', async () => {
    (0, _react.render)((0, _jsxRuntime.jsx)("div", {
      style: {
        width: '200px'
      },
      children: _TruncateText || (_TruncateText = (0, _jsxRuntime.jsxs)(_index.TruncateText, {
        children: ["Hello world!", ' ', (0, _jsxRuntime.jsx)("strong", {
          children: (0, _jsxRuntime.jsx)("span", {
            children: "This is a"
          })
        }), ' ', "long string that should truncate"]
      }))
    }));
    const expectedErrorMessage = 'Some children are too deep in the node tree and will not render.';
    await (0, _react.waitFor)(() => {
      (0, _vitest.expect)(consoleErrorMock).toHaveBeenCalledWith(_vitest.expect.stringContaining(expectedErrorMessage), _vitest.expect.any(String));
    });
  });
  it('should handle the empty string as a child', async () => {
    let error = false;
    try {
      const _render = (0, _react.render)(_TruncateText2 || (_TruncateText2 = (0, _jsxRuntime.jsx)(_index.TruncateText, {
          children: ''
        }))),
        rerender = _render.rerender;
      rerender(_TruncateText3 || (_TruncateText3 = (0, _jsxRuntime.jsx)(_index.TruncateText, {
        children: 'hello world'
      })));
      rerender(_TruncateText4 || (_TruncateText4 = (0, _jsxRuntime.jsx)(_index.TruncateText, {
        children: ''
      })));
    } catch (_e) {
      error = true;
    }
    (0, _vitest.expect)(error).toBe(false);
  });
  it('should meet a11y standards', async () => {
    const _render2 = (0, _react.render)((0, _jsxRuntime.jsx)("div", {
        style: {
          width: '200px'
        },
        children: _TruncateText5 || (_TruncateText5 = (0, _jsxRuntime.jsx)(_index.TruncateText, {
          children: defaultText
        }))
      })),
      container = _render2.container;
    const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
    (0, _vitest.expect)(axeCheck).toBe(true);
  });
});