"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _chai = require("chai");
require("@testing-library/jest-dom");
var _cleanData = _interopRequireDefault(require("../cleanData"));
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

describe('cleanData', () => {
  it('should remove spaces from the end of character data', async () => {
    const data = [['T', 'e', 's', 't', ' ', '...']];
    const options = {
      truncate: 'character',
      ellipsis: '...',
      ignore: [' ']
    };
    const newData = (0, _cleanData.default)(data, options);
    (0, _chai.expect)(newData[0].join('')).to.equal('Test...');
  });
  it('should remove spaces from the end of word data', async () => {
    const data = [['Test ', '...']];
    const options = {
      truncate: 'word',
      ellipsis: '...',
      ignore: [' ']
    };
    const newData = (0, _cleanData.default)(data, options);
    (0, _chai.expect)(newData[0].join('')).to.equal('Test...');
  });
  it('should remove spaces from the middle of character data', async () => {
    const data = [['H', 'e', 'l', 'l', 'o', ' ', '...', ' ', 'w', 'o', 'r', 'l', 'd']];
    const options = {
      truncate: 'character',
      ellipsis: '...',
      ignore: [' ']
    };
    const newData = (0, _cleanData.default)(data, options);
    (0, _chai.expect)(newData[0].join('')).to.equal('Hello...world');
  });
  it('should remove spaces from the middle of word data', async () => {
    const data = [['Hello ', '...', 'world']];
    const options = {
      truncate: 'word',
      ellipsis: '...',
      ignore: [' ']
    };
    const newData = (0, _cleanData.default)(data, options);
    (0, _chai.expect)(newData[0].join('')).to.equal('Hello...world');
  });
  it('should do a thorough cleaning', async () => {
    const data = [['T', 'e', 's', 't', '.', ' ', '...']];
    const options = {
      truncate: 'character',
      ellipsis: '...',
      ignore: [' ', '.']
    };
    const newData = (0, _cleanData.default)(data, options, true);
    (0, _chai.expect)(newData[0].join('')).to.equal('Test...');
  });
  it('should remove spaces from the end of complex character data', async () => {
    let data = [['H', 'e', 'l', 'l', 'o', ' '], ['...']];
    const options = {
      truncate: 'character',
      ellipsis: '...',
      ignore: [' ']
    };
    let newData = (0, _cleanData.default)(data, options);
    const text = newData[0].join('') + newData[1].join('');
    data = [['H', 'e', 'l', 'l', 'o', ' '], ['w', 'o', 'r', 'l', 'd', ' ', '...']];
    newData = (0, _cleanData.default)(data, options);
    const text2 = newData[0].join('') + newData[1].join('');
    (0, _chai.expect)(text).to.equal('Hello...');
    (0, _chai.expect)(text2).to.equal('Hello world...');
  });
  it('should remove spaces from the middle of complex word data', async () => {
    let data = [['Hello ', '...'], ['world']];
    const options = {
      truncate: 'word',
      ellipsis: '...',
      ignore: [' ']
    };
    let newData = (0, _cleanData.default)(data, options);
    const text = newData[0].join('') + newData[1].join('');
    data = [['Hello '], ['...', 'world']];
    newData = (0, _cleanData.default)(data, options);
    const text2 = newData[0].join('') + newData[1].join('');
    (0, _chai.expect)(text).to.equal('Hello...world');
    (0, _chai.expect)(text2).to.equal('Hello...world');
  });
});